NAME

Mojolicious::Plugin::Statsd::Adapter::Memory

VERSION

version 0.06

DESCRIPTION

This adapter for Mojolicious::Plugin::Statsd keeps all recorded stats in its "stats" attribute and does nothing else. It's useful for testing.

OPTIONS

stats

A hashref with a key per stat name recorded. Currently, counters are scalar values and timings are hashrefs with 'samples', 'avg, 'min', 'max' keys. This isn't meant to keep reliable metrics right now.

METHODS

timing

See "timing" in Mojolicious::Plugin::Statsd.

counter

See "counter" in Mojolicious::Plugin::Statsd.

SOURCE

The development version is on github at https://github.com/robrwo/perl-Mojolicious-Plugin-Statsd and may be cloned from https://github.com/robrwo/perl-Mojolicious-Plugin-Statsd.git

SUPPORT

Please report any bugs or feature requests on the bugtracker website https://github.com/robrwo/perl-Mojolicious-Plugin-Statsd/issues

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.

AUTHOR

Meredith Howard <mhoward@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2026 by Meredith Howard <mhoward@cpan.org>.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.