Why not adopt me?
NAME
Mojolicious::Plugin::Statsd::Adapter::Statsd - Statsd UDP recording
VERSION
version 0.06
DESCRIPTION
This adapter for Mojolicious::Plugin::Statsd sends stats immediately over UDP to a statsd service.
OPTIONS
client
This is the underlying statsd client. It defaults to an instance of Net::Statsd::Tiny but any class with compatible methods can be used.
addr
The statsd service address. Defaults to the value of $ENV{STATSD_ADDR}, or localhost:8125.
socket
An IO::Socket::INET. Opened connecting to "addr" when necessary.
METHODS
timing
See "timing" in Mojolicious::Plugin::Statsd.
counter
See "counter" in Mojolicious::Plugin::Statsd.
gauge
See "gauge" in Mojolicious::Plugin::Statsd.
set_add
See "set_add" in Mojolicious::Plugin::Statsd.
SOURCE
The development version is on github at https://github.com/robrwo/perl-Mojolicious-Plugin-Statsd and may be cloned from https://github.com/robrwo/perl-Mojolicious-Plugin-Statsd.git
SUPPORT
Please report any bugs or feature requests on the bugtracker website https://github.com/robrwo/perl-Mojolicious-Plugin-Statsd/issues
When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.
AUTHOR
Meredith Howard <mhoward@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2019, 2026 by Meredith Howard <mhoward@cpan.org>.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.